// Functions used for entity behaviors

const SPIN_EPSILON = 40.0;

// Function that makes entity rotate around
function rotate(me)
{
	local ang = fr_ent_get_orientation(me);
	ang[0] += SPIN_EPSILON*fr_ts();
	ang[1] += SPIN_EPSILON*fr_ts();
	ang[2] += SPIN_EPSILON*fr_ts();
	fr_ent_set_orientation(me,ang);
	// This part only affects materials with emissive parts, like the entity with the 'slate' material
	local anim = (fr_math_cos(fr_t()*180.0)+1.0)/2.0;
	fr_ent_set_emissive(me,[anim,anim,anim]);
}

// Slow rotate
function slowtate(me)
{
	local ang = fr_ent_get_orientation(me);
	ang[0] += SPIN_EPSILON*fr_ts()*0.1;
	// ang[1] += SPIN_EPSILON*fr_ts()*0.2;
	ang[2] += SPIN_EPSILON*fr_ts()*0.2;
	fr_ent_set_orientation(me,ang);
}

// Function that makes entity rotate around z axis
function pan(me)
{
	local ang = fr_ent_get_orientation(me);
	ang[0] += SPIN_EPSILON*fr_ts();
	fr_ent_set_orientation(me,ang);
}

// Function that makes entity rotate around x axis
function roll(me)
{
	local ang = fr_ent_get_orientation(me);
	ang[2] += SPIN_EPSILON*fr_ts();
	fr_ent_set_orientation(me,ang);
}

// A more subtle tumble animation?
function tumble(me)
{
	local ang = fr_ent_get_orientation(me);
	ang[0] += SPIN_EPSILON*0.2*fr_ts();
	ang[1] += SPIN_EPSILON*0.8*fr_ts();
	ang[2] += SPIN_EPSILON*1.3*fr_ts();
	fr_ent_set_orientation(me,ang);
}

// Handles the walkthrough
function walkthrough(me)
{
	local pos = fr_ent_get_position(me);
	local ang = fr_ent_get_orientation(me);
	const poseps = 3.0; // Speed to move
	const angeps = 100.0; // Speed to rotate
	// Moving forward
	if(fr_input_get_button(INPUT_FORWARD))
	{
		local mov = [poseps*fr_ts(),0.0,0.0];
		mov = fr_math_rotate_vector(mov,ang);
		pos = fr_math_add_vector(pos,mov);
	}
	// Moving backward
	if(fr_input_get_button(INPUT_BACKWARD))
	{
		local mov = [-poseps*fr_ts(),0.0,0.0];
		mov = fr_math_rotate_vector(mov,ang);
		pos = fr_math_add_vector(pos,mov);
	}
	// Right
	if(fr_input_get_button(INPUT_RIGHT))
	{
		local mov = [0.0,poseps*fr_ts(),0.0];
		mov = fr_math_rotate_vector(mov,ang);
		pos = fr_math_add_vector(pos,mov);
	}
	// Left
	if(fr_input_get_button(INPUT_LEFT))
	{
		local mov = [0.0,-poseps*fr_ts(),0.0];
		mov = fr_math_rotate_vector(mov,ang);
		pos = fr_math_add_vector(pos,mov);
	}
	// Aim left/right
	ang[0] -= fr_input_aim_x()*0.2;
	ang[1] -= fr_input_aim_y()*0.2;
	// Update both the entity and camera
	fr_ent_set_position(me,pos);
	fr_ent_set_orientation(me,ang);
	fr_camera_set_position(pos);
	fr_camera_set_orientation(ang);
}
